python-asdl
=================

.. image:: https://travis-ci.org/fpoli/python-asdl.svg?branch=master
    :target: https://travis-ci.org/fpoli/python-asdl

A copy of the ASDL parser used in CPython 3.5, cleaned a bit and packaged here.


Installation
------------

.. code-block:: bash

    $ pip install asdl


Usage
-----

.. code-block:: python

    import asdl
    print(asdl.parse("./test/Python.asdl"))


License
-------

Same as CPython: Python Software Foundation License (LICENSE file included
here).
